@@ -1,10 +1,14 @@
+import cProfile
 import csv
 import io
 import itertools
 import json
+import marshal
+import pstats
 import sys
 
 import django.contrib.admin.views.decorators as admin_decorators
+import sqlparse
 from django import http
 from django.core.serializers.json import DjangoJSONEncoder
 from django.shortcuts import get_object_or_404
@@ -19,7 +23,7 @@ from .common import HttpResponse, JsonResponse, can_make_public, settings
 from .models import View
 from .orm_admin import get_models
 from .orm_fields import OPEN_IN_ADMIN
-from .orm_results import get_results
+from .orm_results import get_result_queryset, get_results
 from .query import BoundQuery, Query
 from .types import TYPES
 
@@ -70,7 +74,11 @@ def _get_model_fields(orm_model):
         for name, orm_field in orm_model.fields.items()
     }
 
-    return {"fields": all_fields, "sortedFields": sort_model_fields(all_fields)}
+    return {
+        "fields": all_fields,
+        "sortedFields": sort_model_fields(all_fields),
+        "defaultFilters": orm_model.default_filters,
+    }
 
 
 def _get_config(request):
@@ -134,8 +142,13 @@ def query_html(request, *, model_name="", fields=""):
 
 @admin_decorators.staff_member_required
 def query(request, *, model_name, fields="", media):
+    profiler = None
+    if media in {"profile", "pstats"}:
+        profiler = cProfile.Profile()
+        profiler.enable()
+
     query = Query.from_request(model_name, fields, request.GET)
-    return _data_response(request, query, media, meta=True)
+    return _data_response(request, query, media, privilaged=True, profiler=profiler)
 
 
 def view(request, pk, media):
@@ -149,7 +162,7 @@ def view(request, pk, media):
     ):
         request.user = view.owner  # public views are run as the person who owns them
         query = view.get_query()
-        return _data_response(request, query, media, meta=False)
+        return _data_response(request, query, media, privilaged=False)
     else:
         raise http.Http404("No View matches the given query.")
 
@@ -185,13 +198,41 @@ def pad_table(x, table):
     return [pad(x) + row for row in table]
 
 
-def _data_response(request, query, media, meta):
+def _data_response(request, query, media, privilaged=False, profiler=None):
     orm_models = get_models(request)
     if query.model_name not in orm_models:
         raise http.Http404(f"{query.model_name} does not exist")
     bound_query = BoundQuery.bind(query, orm_models)
 
-    if media == "csv":
+    if profiler:
+        # get the results
+        results = get_results(request, bound_query, orm_models)
+        resp = _get_query_data(bound_query) if privilaged else {}
+        resp.update(results)
+
+        # and throw them away and stop profiling
+        del resp
+        profiler.disable()
+
+        if media == "profile":
+            buffer = io.StringIO()
+            stats = pstats.Stats(profiler, stream=buffer)
+            stats.sort_stats("cumulative").print_stats(50)
+            stats.sort_stats("time").print_stats(50)
+            buffer.seek(0)
+            return HttpResponse(buffer, content_type="text/plain")
+        elif media == "pstats":
+            buffer = io.BytesIO()
+            marshal.dump(pstats.Stats(profiler).stats, buffer)
+            buffer.seek(0)
+            response = HttpResponse(buffer, content_type="application/octet-stream")
+            response[
+                "Content-Disposition"
+            ] = f"attachment; filename={query.model_name}-{timezone.now().isoformat()}.pstats"
+            return response
+        else:
+            assert False
+    elif media == "csv":
         results = get_results(request, bound_query, orm_models)
         buffer = io.StringIO()
         writer = csv.writer(buffer)
@@ -225,19 +266,25 @@ def _data_response(request, query, media, meta):
         )
 
         buffer.seek(0)
-        response = HttpResponse(buffer, content_type="text")
+        response = HttpResponse(buffer, content_type="text/csv")
         response[
             "Content-Disposition"
         ] = f"attachment; filename={query.model_name}-{timezone.now().isoformat()}.csv"
         return response
     elif media == "json":
         results = get_results(request, bound_query, orm_models)
-        resp = _get_query_data(bound_query) if meta else {}
+        resp = _get_query_data(bound_query) if privilaged else {}
         resp.update(results)
         return JsonResponse(resp)
-    elif media == "query":
-        resp = _get_query_data(bound_query) if meta else {}
+    elif privilaged and media == "query":
+        resp = _get_query_data(bound_query)
         return JsonResponse(resp)
+    elif privilaged and media == "sql":
+        query_set = get_result_queryset(request, bound_query, orm_models)
+        return HttpResponse(
+            sqlparse.format(str(query_set.query), reindent=True, keyword_case="upper"),
+            content_type="text/plain",
+        )
     else:
         raise http.Http404(f"Bad file format {media} requested")
 
