@@ -100,8 +100,10 @@ class ProductMixin:
         "hidden_model",
         "boat",
         "duration",
+        "date",
     ]
     readonly_fields = ["id", "is_onsale", "hidden_calculated"]
+    ddb_default_filters = "default=filter&filter=default"
 
     @ddb_hide
     def hidden_calculated(self, obj):
